@@ -18,6 +18,7 @@
 #include "pdfimage.h"
 #include "pdfimage_p.h"
 #include "pdfdocument_p.h"
+#include "popplerglobalparams_p.h"
 #include "popplerutils_p.h"
 
 #include <QDebug>
@@ -35,7 +36,7 @@ using namespace KItinerary;
 
 #ifdef HAVE_POPPLER
 // legacy image loading
-#ifndef HAVE_POPPLER_0_69
+#if KPOPPLER_VERSION < QT_VERSION_CHECK(0, 69, 0)
 namespace KItinerary {
 class ImageLoaderOutputDevice : public OutputDev
 {
@@ -148,9 +149,9 @@ QImage PdfImagePrivate::load()
     }
 
 #ifdef HAVE_POPPLER
-    QScopedValueRollback<GlobalParams*> globalParamResetter(globalParams, PopplerUtils::globalParams());
+    PopplerGlobalParams gp;
 
-#ifdef HAVE_POPPLER_0_69
+#if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 69, 0)
     const auto xref = m_page->m_doc->m_popplerDoc->getXRef();
     const auto obj = xref->fetch(m_refNum, m_refGen);
     return load(obj.getStream(), m_colorMap.get());
